Citation - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Citation

`betty.model.ancestry.Citation` entities link ‘facts’ with sources.

## Fields

Citations inherit from:

- Privacy

`date` (Datey)

  The citation (access) date.

`facts` (iterable of any entity)

  The entities this citation bridges to `source`.

`files` (iterable of File)

  The files attached to this citation.

`id` (`str`)

  The citation’s own entity ID.

`location` (`str`)

  A description of which part of `source` this citation references.

`source` (Source)

  The source the `facts` are bridged to.